@@ -851,6 +851,9 @@ static struct input_types input_types[] = {
 { "--fsia6b",		"-fsia6b",	"FS-iA6B RC Receiver",
 	B115200, CS8,
 	SERIO_FSIA6B,		0x00,	0x00,	0,	NULL },
+{ "--gunze",		"-gunze",	"Gunze touchscreen",
+	B9600, CS8,
+	SERIO_GUNZE,		0x00,	0x00,	0,	NULL },
 { "--hampshire",	"-ham",		"Hampshire touchscreen",
 	B9600, CS8,
 	SERIO_HAMPSHIRE,	0x00,   0x00,   0,	NULL },
