@@ -63,6 +63,7 @@ __u16 buttonmap[(KEY_MAX - BTN_MISC + 1)];
 char axes, buttons, fuzz;
 int version;
 struct correction_data corda[ABS_MAX + 1];
+int button = -1, buttonno = -1;
 
 struct js_info {
 	int buttons;
@@ -154,6 +155,7 @@ void help(void)
 	puts("Usage: jscal <device>");
 	putchar('\n');
 	puts("  -c             --calibrate         Calibrate the joystick");
+	puts("  -b <number>    --button            Button to continue calibrating");
 	puts("  -h             --help              Display this help");
 	puts("  -s <x,y,z...>  --set-correction    Sets correction to specified values");
 	puts("  -t             --test-center       Tests if joystick is corectly calibrated");
@@ -265,16 +267,28 @@ void calibrate()
 
 
 	b = js.buttons;
+	const char * push_msg;
+	if(button == -1) {
+		push_msg = "Move axis %d to %s position and push any button.\n";
+	}else{
+		push_msg = "Move axis %d to %s position and push button %d.\n";
+	}
 
 	for (axis = 0; axis < axes; axis++)
 		for (pos = 0; pos < NUM_POS; pos++) {
 			while(b ^ js.buttons) wait_for_event(fd, &js);
-			printf("Move axis %d to %s position and push any button.\n", axis, pos_name[pos]);
+			printf(push_msg, axis, pos_name[pos], buttonno);
 
-			while (!(b ^ js.buttons)) {
-				print_position(axis, js.axis[axis]);
-				wait_for_event(fd, &js);
-			}
+			if(button == -1)
+				while (!(b ^ js.buttons)) {
+					print_position(axis, js.axis[axis]);
+					wait_for_event(fd, &js);
+				}
+			else
+                                while (!(js.buttons & button)) {
+                                        print_position(axis, js.axis[axis]);
+                                        wait_for_event(fd, &js);
+                                }
 
 			putcs("Hold ... ");
 
@@ -670,6 +684,7 @@ int main(int argc, char **argv)
   // /usr/include/getopt.h
 	static struct option long_options[] =
 	{
+		{"button", required_argument, NULL, 'b'},
 		{"calibrate", no_argument, NULL, 'c'},
 		{"help", no_argument, NULL, 'h'},
 		{"set-correction", required_argument, NULL, 's'},
@@ -687,7 +702,7 @@ int main(int argc, char **argv)
 	}
 
 	do {
-		t = getopt_long(argc, argv, "chpqu:s:vVt", long_options, &option_index);
+		t = getopt_long(argc, argv, "b:chpqu:s:vVt", long_options, &option_index);
 		switch (t) {
 			case 'p':
 			case 'q':
@@ -701,9 +716,13 @@ int main(int argc, char **argv)
 					exit(1);
 				} else {
 					action = t;
-					if ((parameter=optarg)) strcpy(parameter,optarg);
+					parameter = optarg;
 				}
 				break;
+			case 'b':
+				buttonno = atoi(optarg);
+				button = 1 << buttonno;
+				break;
 			case 'h':
 				help();
 				exit(0);
